@@ -27,6 +27,10 @@ class BaseContext:
     async def callback(self, content: str = '', embeds: list[Embed] = [], embed: Embed = None, components: list[ActionRow] = [], ephemeral: bool = False, _type: int = utils.CHANNEL_WITH_SOURCE):
         if len(embeds) > 0 and embed is not None:
             _embeds = embeds.insert(0, embed)
+        
+        elif embed is not None and len(embeds) == 0:
+            _embeds = [embed]
+
         else:
             _embeds = embeds
 
@@ -44,7 +48,6 @@ class BaseContext:
 
         await self.__http.make_request('POST', f"interactions/{self.id}/{self.token}/callback", response_json)
         self.message = Message(self.__http, await self.__http.make_request('GET', f"webhooks/{self.raw['application_id']}/{self.token}/messages/@original"))
-        print(self.message)
 
 class SelectMenuContext(BaseContext):
     def __init__(self, http_client, data):
